@@ -9,13 +9,13 @@
 #
 package Config::Model::Tester;
 # ABSTRACT: Test framework for Config::Model
-$Config::Model::Tester::VERSION = '2.061';
+
 use warnings;
 use strict;
 use locale;
 use utf8;
 use 5.10.1;
-
+our $VERSION=3;
 use Test::More;
 use Log::Log4perl 1.11 qw(:easy :levels);
 use Path::Tiny;
@@ -324,6 +324,11 @@ sub write_data_back {
 sub check_file_mode {
     my ($wr_dir, $t) = @_;
 
+    if ($^O eq 'MSWin32' and my $fm = $t->{file_mode}) {
+        note("skipping file mode tests on Windows");
+        return;
+    }
+
     if (my $fm = $t->{file_mode}) {
         foreach my $f (keys %$fm) {
             my $expected_mode = $fm->{$f} ;
@@ -621,7 +626,7 @@ Config::Model::Tester - Test framework for Config::Model
 
 =head1 VERSION
 
-version 2.061
+version 2.062
 
 =head1 SYNOPSIS
 
@@ -1096,6 +1101,8 @@ Check the mode of the written files:
 Only the last four octets of the mode are tested. I.e. the test is done with
 C< $file_mode & 07777 >
 
+Note: this test is skipped on Windows
+
 =item *
 
 Check added or removed configuration files. If you expect changes,
